# 📺 yt-mpv

Watch a YouTube video without ads, while archiving to archive.org.

```bash
uvx yt-mpv install
```

Follow instructions to configure internet archive credentials, then drag the link
to your bookmarks bar. Clicking it will open mpv (takes a couple of seconds).
Afterwards, it'll download it again in highest quality in the background, and
upload it to archive.org

You'll need to install `mpv` in order to use it, and have an archive.org account
to configure the `internetarchive` uploader.

## why?

This is what you get when you put 4 minutes of adverts after every 6 minutes
of content; someone spends a couple of hours fixing the problem.

## links

* [🏠 home](/dev/python/yt-mpv)
* [🐍 pypi](https://pypi.org/project/yt-mpv/)
* [🐱 github](https://github.com/bitplane/yt-mpv)

